<?php
/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Twenty Fifteen 1.0
 *
 * @see wp_add_inline_style()
 */
function splitvcard_color_scheme_css() {
	global $splitvcard_option;
	wp_add_inline_style( 'splitvcard-style', splitvcard_get_color_scheme_css() );
}
add_action( 'wp_enqueue_scripts', 'splitvcard_color_scheme_css' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Twenty Fifteen 1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function splitvcard_get_color_scheme_css() {
	global $splitvcard_option;


	if(!isset($splitvcard_option['main_color_rgba']['rgba']))
	{
		$splitvcard_option['main_color_rgba']['rgba']="rgba(205,83,83,1)";
	}

	$css = <<<CSS
	/* Color Scheme */

	.divider-m .zigzag.medium,
	.divider .zigzag.large {
	    stroke:{$splitvcard_option['main_color']};
	}

	.but.opc-2 {
	    background:{$splitvcard_option['main_color']};
	    /* Prevent background color leak outs */
	    -webkit-background-clip: padding-box;
	    -moz-background-clip: padding;
	    background-clip: padding-box;
	}

	.but.opc-3 {
	    background:{$splitvcard_option['main_color']};
	    /* Prevent background color leak outs */
	    -webkit-background-clip: padding-box;
	    -moz-background-clip: padding;
	    background-clip: padding-box;
	}

	.main-nav li a:before {
	    background:{$splitvcard_option['main_color']};
	}

	.main-nav li a.active:before {
	    background:{$splitvcard_option['main_color']};
	}

	.main-nav li a.active {
	    background:{$splitvcard_option['main_color']};
	}

	.social a:hover {
	    border: 2px solid{$splitvcard_option['main_color']};
	    color:{$splitvcard_option['main_color']};
	}

	.skill.dev .progress {
	    border: 1px solid{$splitvcard_option['main_color']};
	}

	.skill.dev .progress .percentage {
	    background-color:{$splitvcard_option['main_color']};
	}

	.skill .title.dev {
	    border: 1px dashed{$splitvcard_option['main_color']};
	}

	.exp:after {
	    background:{$splitvcard_option['main_color']};
	}

	.exp .hgroup h6 span.current {
	    background:{$splitvcard_option['main_color']};
	}

	.block.service .ico {
	    color:{$splitvcard_option['main_color']};
	}

	.filter li a:hover {
	    color:{$splitvcard_option['main_color']};
	}

	.filter li a.active {
	    color:{$splitvcard_option['main_color']};
	}

	.block-nav-work li a:hover {
	    color:{$splitvcard_option['main_color']};
	}

	span.meta-date {
	    background:{$splitvcard_option['main_color']};
	}

	.post-meta li a, .nav-links a:hover {
	    color:{$splitvcard_option['main_color']};
	}

	.search-form input[type="text"] {
	    background:{$splitvcard_option['main_color']};
	}

	.comments .reply-btn a, .owl-theme .owl-controls .owl-page.active span, .owl-theme .owl-controls.clickable .owl-page:hover span {
	    background:{$splitvcard_option['main_color']};
	}

	.comment-content .date a, .pagination ul li a:hover, .pagination ul li span.current {
	    color:{$splitvcard_option['main_color']};
	}

	.pagination ul li a.selected, .comment-content .date a, .comment-content .date span {
	    color:{$splitvcard_option['main_color']};
	}

	.errorForm {
	    border: 1px solid{$splitvcard_option['main_color']} !important;
	}

	.address-info i, .search-form input[type="search"] {
	    background:{$splitvcard_option['main_color']};
	}

	.wpcf7-form .wpcf7-not-valid {
	  border-color:{$splitvcard_option['main_color']} !important;
	}

	.item a .desc {
	    background-color: {$splitvcard_option['main_color_rgba']['rgba']};
	}

CSS;

	return $css;
}