<?php
/**
 * Register meta boxes
 *
 * @since 1.0
 *
 * @param array $meta_boxes
 *
 * @return array
 */
function splitvcard_register_meta_boxes( $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cmb_';

	// Post format
	$meta_boxes[] = array(
		'id'       => 'format_detail',
		'title'    => esc_attr__( 'Format Details', 'splitvcard' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => esc_attr__( 'Image', 'splitvcard' ),
				'id'               => $prefix . 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => esc_attr__( 'Gallery', 'splitvcard' ),
				'id'    => $prefix . 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'             => esc_attr__( 'Image', 'splitvcard' ),
				'id'               => $prefix . 'avatar',
				'type'             => 'image_advanced',				
				'max_file_uploads' => 1,
				'class' => 'quote',
			),
			array(
				'name'  => esc_attr__( 'Quote', 'splitvcard' ),
				'id'    => $prefix . 'quote',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'quote',
			),
			array(
				'name'  => esc_attr__( 'Author', 'splitvcard' ),
				'id'    => $prefix . 'quote_author',
				'type'  => 'text',
				'class' => 'quote',
			),			
			array(
				'name'  => esc_attr__( 'Audio', 'splitvcard' ),
				'id'    => $prefix . 'link_audio',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio',
				'desc' => 'Ex: https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/139083759',
			),
			array(
				'name'  => esc_attr__( 'Video', 'splitvcard' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>http://www.youtube.com/embed/0ecv0bT9DEo</b> or <b>http://player.vimeo.com/video/47355798</b>',
			),	
		),
	);	

    $meta_boxes[] = array(
        'id'         => 'format_detail',
        'title'      => 'Portfolio Setting',
        'pages'      => array('portfolio'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(                       
            array(
				'name'             => esc_attr__( 'Upload your image popup', 'splitvcard' ),
				'id'               => $prefix . 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),								
			array(
				'name'  => esc_attr__( 'Add your video link for popup.', 'splitvcard' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'oembed',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>https://www.youtube.com/watch?v=gTFljCRnGN4</b> or <b>https://vimeo.com/67429593</b>',
			),	  
			array(
				'name'  => esc_attr__( 'Add link to your project.', 'splitvcard' ),
				'id'    => $prefix . 'link_out',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'link',
				'desc' => 'Example: http://themeforest.net/user/oceanthemes/portfolio',
			),	   
			array(
				'name'  => esc_attr__( 'Select link to your single project or popup an image, video, link out.', 'splitvcard' ),
				'id'    => $prefix . 'link_type',
				'type'  => 'select',
				'class' => 'audio quote video image link gallery aside status chat 0',
				'options' => array(
						'link_single' => 'Link to single project.',
						'popup' => 'Popup an image, video, link out.'					
                    ),
				'std' => 'link_single'								
			),	 
			array(
				'name'  => esc_attr__( 'Add link to your project online.', 'splitvcard' ),
				'id'    => $prefix . 'link_online',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio quote video image link gallery aside status chat 0',
				'desc' => 'It is button use on bottom single project page, Example: http://themeforest.net/user/oceanthemes/portfolio',
			),
			array(
				'name'  => esc_attr__( 'Add button text.', 'splitvcard' ),
				'id'    => $prefix . 'button_text',
				'type'  => 'text',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio quote video image link gallery aside status chat 0',
				'desc' => 'It is button use on bottom single project page, Example: view project online',
			),	           
        )
    );

	// Add other metaboxes as needed
	$meta_boxes[] = array(
		'id'       => 'testimonial_job',
		'title'    => esc_attr__( 'Job Of Person', 'splitvcard' ),
		'pages'    => array( 'testimonial'),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'  => esc_attr__( 'Add Job / Company', 'splitvcard' ),
				'id'    => $prefix . 'job',
				'type'  => 'text',
			),
		),
	);

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'splitvcard_register_meta_boxes' );
