<?php
/**
 * Custom template tags for Split Vcard
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package WordPress
 * @subpackage Split_Vcard
 * @since Split Vcard 1.0
 */

if ( ! function_exists( 'splitvcard_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since Split Vcard 1.0
 */
function splitvcard_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'splitvcard' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'splitvcard' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'splitvcard' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'splitvcard_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 *
 * @since Split Vcard 1.0
 */
function splitvcard_entry_meta() {

	echo '<div class="post-title">';

		if ( ! is_single() ) {
			echo '<a href="'.get_permalink().'"><h1>';
			echo get_the_title();
			echo '</h1></a>';
		}else{
			echo '<h1>'.get_the_title().'</h1>';
		}


        if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
			}

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				get_the_date(),
				esc_attr( get_the_modified_date( 'c' ) ),
				get_the_modified_date()
			);

			printf( '<span class="meta-date">%3$s</span>',
				_x( '', 'Used before publish date.', 'splitvcard' ),
				esc_url( get_permalink() ),
				$time_string
			);
		}

    echo '</div>';

	echo '<ul class="post-meta">';

	if ( 'post' == get_post_type() ) {

		printf( '<li class="byline"><i class="icon-user-7"></i><span class="author vcard">%1$s </span><a class="url fn n" href="%2$s">%3$s</a></li>',
			_x( 'Post by', 'Used before post author name.', 'splitvcard' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			get_the_author()
		);

		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'splitvcard' ) );
		if ( $categories_list ) {
			printf( '<li class="cat-links"><i class="icon-folder-open"></i><span class="screen-reader-text">%1$s </span>%2$s</li>',
				_x( 'Categories', 'Used before category names.', 'splitvcard' ),
				$categories_list
			);
		}
	}

	if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<li class="comments-link"><i class="icon-comment-2"></i>';
		/* translators: %s: post title */
		comments_popup_link( '<span>Comment</span> (0)', '<span>Comment</span> (1)', '<span>Comments</span> (%)', 'comments-link', 'Comments are off for this post');
		echo '</li>';
	}
	echo '</ul>';
}
endif;

if ( ! function_exists( 'splitvcard_entry_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 *
 * @since Split Vcard 1.0
 */

function splitvcard_entry_tags() {

	echo '<ul class="post-meta post-tags">';

	if ( 'post' == get_post_type() ) {


		$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'splitvcard' ) );
		if ( $tags_list ) {
			printf( '<li class="tags-links"><i class="icon-layout"></i><span>%1$s </span>%2$s</li>',
				_x( 'Tagged in', 'Used before tag names.', 'splitvcard' ),
				$tags_list
			);
		}
	}

	echo '</ul>';
}

endif;

if ( ! function_exists( 'splitvcard_pagination' ) ) :
//pagination
function splitvcard_pagination($prev = '<i class="icon-left-open-mini"></i>', $next = '<i class="icon-right-open-mini"></i>', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }

    $pagination = array(
		'base' 			=> str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
		'format' 		=> '',
		'current' 		=> max( 1, get_query_var('paged') ),
		'total' 		=> $pages,
		'prev_text' => $prev,
        'next_text' => $next,
        'type'			=> 'list',
		'end_size'		=> 3,
		'mid_size'		=> 3
);
    $return =  paginate_links( $pagination );
	echo str_replace( "<ul class='page-numbers'>", '<ul>', $return );
}
endif;

/* Custom comment List: */
function splitvcard_theme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>

   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<div class="author-img">
				<?php echo get_avatar($comment,$size='70',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536' ); ?>
				<div class="reply-btn">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply', 'splitvcard' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div>
			</div>
			<div class="comment-content">
				<div class="comments-info">
					<div class="author"><span><?php comment_author_link(); ?></span></div>
					<div class="date"><span><?php comment_date('F j, Y \a\t g:i a'); ?></span></div>
				</div>
				<?php if ($comment->comment_approved == '0'){ ?>
					 <p class="expert"><em><?php esc_html_e('Your comment is awaiting moderation.','splitvcard') ?></em></p>
				<?php }else{ ?>
		            <div class="class="expert""><?php comment_text() ?></div>
		         <?php } ?>
			</div>
		</article>
	</li>

<?php
}

if ( ! function_exists( 'splitvcard_custom_wp_admin_style' ) ) :
function splitvcard_custom_wp_admin_style() {

        wp_register_style( 'splitvcard_custom_wp_admin_css', get_template_directory_uri() . '/inc/admin/admin-style.css', false, '1.0.0' );
        wp_enqueue_style( 'splitvcard_custom_wp_admin_css' );

        wp_enqueue_script( 'eleos-backend-js', get_template_directory_uri()."/inc/admin/admin-script.js", array( 'jquery' ), '1.0.0', true );
        wp_enqueue_script( 'eleos-backend-js' );
}
add_action( 'admin_enqueue_scripts', 'splitvcard_custom_wp_admin_style' );
endif;

if ( ! function_exists( 'splitvcard_search_form' ) ) :
/* Custom form search */
function splitvcard_search_form( $form ) {
    $form = '<div class="search-header">
	    		<form role="search" class="search-form" method="get" action="' . esc_url(home_url( '/' )) . '" >
	                <input type="search" id="search" class="search-field" value="' . get_search_query() . '" name="s" placeholder="'.esc_html__('Search', 'splitvcard').'" />
	            	<input type="submit" class="search-submit" value="' . esc_html__( 'Search', 'splitvcard' ) . '" />
					<i class="icon-search-2"></i>
	            </form>
            </div>';
    return $form;
}
add_filter( 'get_search_form', 'splitvcard_search_form' );
endif;

if ( ! function_exists( 'splitvcard_custom_avatar' ) ) :
/**
 * Prints HTML with Custom Logo.
 */
function splitvcard_custom_avatar() {
    global $splitvcard_option;
	if($splitvcard_option['avatar_switch']==true){
?>
    <figure class="img-profile">
		<img src="<?php echo esc_url($splitvcard_option['avatar']['url']); ?>" alt="Image Description"/>
		<figcaption class="name-profile">
			<span><?php echo wp_specialchars_decode($splitvcard_option['your_name']); ?></span>
		</figcaption>
	</figure>
<?php
}
}
endif;

if ( ! function_exists( 'splitvcard_custom_preload' ) ) :
/**
 * Prints HTML with Custom Preload.
 */
function splitvcard_custom_preload() {
    global $splitvcard_option;
    if($splitvcard_option['preload-switch']==true){
?>
    <div id="loader">
      <div id="loaderInner">
    	<div class="spinner"></div>
      </div>
    </div>
<?php
	}
}
endif;


if ( ! function_exists( 'splitvcard_custom_footer_text' ) ) :
/**
 * Prints HTML with Custom Footer Text.
 */
function splitvcard_custom_footer_text() {
    global $splitvcard_option;
    echo wp_kses($splitvcard_option['footer_text'] , wp_kses_allowed_html('post') );
}
endif;

if ( ! function_exists( 'splitvcard_custom_social_network' ) ) :
/**
 * Prints HTML with Custom Social Network.
 */
function splitvcard_custom_social_network() {
    global $splitvcard_option;
?>
    <ul class="social">
	    <?php if($splitvcard_option['facebook']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['facebook']); ?>"><i class="icon-facebook"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['twitter']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['twitter']); ?>"><i class="icon-twitter"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['google']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['google']); ?>"><i class="icon-google"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['dribbble']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['dribbble']); ?>"><i class="icon-dribbble"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['pinterest']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['pinterest']); ?>"><i class="icon-pinterest"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['linkedin']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['linkedin']); ?>"><i class="icon-linkedin"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['youtube']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['youtube']); ?>"><i class="icon-youtube-1"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['vimeo']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['vimeo']); ?>"><i class="icon-vimeo-1"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['rss']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['rss']); ?>"><i class="icon-rss"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['skype']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_attr($splitvcard_option['skype']); ?>"><i class="icon-skype"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['instagram']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['instagram']); ?>"><i class="icon-instagram"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['github']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['github']); ?>"><i class="icon-github"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['tumblr']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['tumblr']); ?>"><i class="icon-tumblr-1"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['soundcloud']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['soundcloud']); ?>"><i class="icon-soundcloud"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['behance']!=''){ ?>
           <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['behance']); ?>"><i class="icon-behance"></i></a></li>
        <?php } ?>
        <?php if($splitvcard_option['lastfm']!=''){ ?>
            <li><a target="_blank" href="<?php echo esc_url($splitvcard_option['lastfm']); ?>"><i class="icon-lastfm"></i></a></li>
        <?php } ?>
	</ul>
	<?php
		if ($splitvcard_option['copyright'] != '') {
			echo '<p>' . wp_specialchars_decode($splitvcard_option['copyright']) . '</p>';
		}
	?>
<?php
}
endif;